@@ -21,7 +21,6 @@
 
 package HTML::TableParser;
 
-require 5.8.1;
 use strict;
 use warnings;
 
@@ -30,12 +29,9 @@ use HTML::Parser;
 
 use HTML::TableParser::Table;
 
-## no critic ( ProhibitAccessOfPrivateData )
-
-
 our @ISA = qw(HTML::Parser);
 
-our $VERSION = '0.38_02';
+our $VERSION = '0.35';
 
 # Preloaded methods go here.
 
